### Name: plot.fkf
### Title: Plotting fkf Objects
### Aliases: plot.fkf
### Keywords: hplot

### ** Examples

## This example shows how to filter a series by an AR(2) filter

ar1 <- -0.44
ar2 <- 0.4
sigma <- .4

## Sample from an AR(2) process and put it into the Kalman filter
a <- arima.sim(model = list(ar = c(ar1, ar2)),
               n = 60, innov = rnorm(60) * sigma)

## Set up the state space representation for an AR(2) model:
## Transition equation:
## alpha[, t + 1] = matrix(ar1, 1, ar2, 0, ncol = 2) * alpha[,t] + e[t]
## Measurement equation:
## y[,t] = c(1, 0) * a[,t] */
## Initial values:
## a0 = c(0, 0), P0 = diag(c(10, 10))

ans <- fkf(a0 = c(0, 0), P0 = diag(c(10, 10)),
           dt = rbind(0, 0), ct = matrix(0),
           Tt = matrix(c(ar1, 1, ar2, 0), ncol = 2),
           Zt = cbind(1, 0),
           HHt = matrix(c(sigma^2, 0, 0, 0), ncol = 2),
           GGt = matrix(0), yt = rbind(a))

## Compared the filtered series with the simulated AR(2) series:
plot(ans, att.idx = 1, at.idx = NA)
lines(a, lty = "dotted")

## Compared the predicted series with the simulated AR(2) series.
## Additionally, a 99
plot(ans, att.idx = NA, at.idx = 1, CI = .99)
lines(a, lty = "dotted")

## Check the residuals for normality
plot(ans, type = "resid.qq")

## Test for autocorrelation
plot(ans, type = "acf")




